pub fn install_panic_hook()Expand description
Route every panic (any thread) through tracing with a backtrace, so it reaches the log file, the ring and the UI. Idempotent.
pub fn install_panic_hook()Route every panic (any thread) through tracing with a backtrace, so it reaches the log file, the ring and the UI. Idempotent.